import { describe, it, expect } from 'vitest';
import { getCallerName } from '../src/misc.js';

describe('getCallerName', () => {
  it('возвращает имя вызывающей функции по умолчанию', () => {
    function testFunction() {
      const callerName = getCallerName();
      expect(callerName).toBe('testFunction');
    }
    testFunction();
  });

  it('возвращает "anonymous", если уровень стека вне границ', () => {
    function testFunction() {
      const callerName = getCallerName(100);
      expect(callerName).toBe('anonymous');
    }
    testFunction();
  });

  it('обрабатывает анонимные функции корректно', () => {
    const callerName = (function () {
      return getCallerName(3);
    })();
    expect(callerName).toBe('anonymous');
  });

  it('возвращает правильное имя вызывающей функции на заданном уровне', () => {
    function levelOne() {
      return levelTwo();
    }

    function levelTwo() {
      return getCallerName(2); // Уровень зависит от среды, может потребоваться подгонка
    }

    const callerName = levelOne();
    expect(callerName).toBe('levelOne');
  });

  it('возвращает "anonymous", если стек не определён', () => {
    const OriginalError = globalThis.Error;

    globalThis.Error = class extends OriginalError {
      constructor(...args) {
        super(...args);
        this.stack = null;
      }
    };

    const callerName = getCallerName();
    expect(callerName).toBe('anonymous');

    globalThis.Error = OriginalError;
  });
});
