import { describe, it, expect, beforeEach, afterEach } from 'vitest';
import path from 'path';
import { getConfig, checkEnumValue, getConfigItem } from '../src/misc.js';

describe('getConfig', () => {
  it('returns config object from existing config file', async () => {
    const config = {
      key: 'value',
      fileName: path.join(path.resolve('./'), '__tests__/assets/config.jsonc'),
    };
    const root = './__tests__';
    const configScope = ['assets/config.json', 'assets/config.jsonc'];

    const result = await getConfig(root, configScope);

    expect(result).toStrictEqual(config);
  });

  it('returns undefined if configScope is not provided', async () => {
    const root = './__tests__';
    const configScope = undefined;

    const result = await getConfig(root, configScope);

    expect(result).toBeUndefined();
  });
});

describe('checkEnumValue', () => {
  it('returns true for valid enum value', () => {
    const enumObject = { ONE: 'one', TWO: 'two' };
    const value = 'one';

    const result = checkEnumValue(value, enumObject);

    expect(result).toBe(true);
  });

  it('returns false for invalid enum value', () => {
    const enumObject = { ONE: 'one', TWO: 'two' };
    const value = 'three';

    const result = checkEnumValue(value, enumObject);

    expect(result).toBe(false);
  });
});

describe('getConfigItem', () => {
  const ENV_VAR = 'TEST_ITEM';

  beforeEach(() => {
    process.env[ENV_VAR] = 'test value';
  });

  afterEach(() => {
    delete process.env[ENV_VAR];
  });

  it('gets value from environment variable', async () => {
    const param = { env: ENV_VAR };
    const result = await getConfigItem(param);

    expect(result).toBe('test value');
  });
});
