import { describe, it, expect } from 'vitest';
import { isTextMatch, getRandomString, matchesAnyRegExp } from '../src/strings';

describe('isTextMatch', () => {
  it('matches plain text', () => {
    const result = isTextMatch('test', 'test');
    expect(result).toBe(true);
  });

  it('does not match different plain text', () => {
    const result = isTextMatch('test', 'another text');
    expect(result).toBe(false);
  });

  it('matches with regexp (no flags)', () => {
    const result = isTextMatch('test', 'te.*', true);
    expect(result).toBe(true);
  });

  it('does not match with regexp (case sensitive)', () => {
    const result = isTextMatch('test', 'Te.*', true);
    expect(result).toBe(false);
  });

  it('matches with regexp and flags', () => {
    const result = isTextMatch('test', 'Te.*', true, 'i');
    expect(result).toBe(true);
  });

  it('does not match with regexp and flags', () => {
    const result = isTextMatch('test', 'Ti.*', true, 'i');
    expect(result).toBe(false);
  });
});

describe('getRandomString', () => {
  it('generates string of specified length', () => {
    const result = getRandomString(32);
    expect(result.length).toBe(32);
  });
});

describe('matchesAnyRegExp', () => {
  it('returns false with empty regex array', () => {
    const result = matchesAnyRegExp('test', []);
    expect(result).toBe(false);
  });

  it('returns true if string matches any regex in array', () => {
    const result = matchesAnyRegExp('example text', [/test/, /example/]);
    expect(result).toBe(true);
  });

  it('returns false if string does not match any regex', () => {
    const result = matchesAnyRegExp('another text', [/test/, /example/]);
    expect(result).toBe(false);
  });

  it('is case-sensitive by default', () => {
    const result = matchesAnyRegExp('TEST', [/test/]);
    expect(result).toBe(false);
  });

  it('respects "i" flag for case-insensitive matching', () => {
    const result = matchesAnyRegExp('TEST', [/test/i]);
    expect(result).toBe(true);
  });
});
