'use strict';

import fs from 'fs';
import path, { dirname } from 'path';
import { minimatch } from 'minimatch';

export function isFileExists(filePath) {
  return new Promise((resolve, reject) => {
    fs.access(filePath, fs.constants.F_OK, (err) => {
      if (err) {
        resolve(false);
      } else {
        resolve(true);
      }
    });
  });
}

export function getAllFilePaths(rootDir = './', fileMask, absolutePath = false, pathPrefix = '') {
  const filePaths = [];

  if (!absolutePath) pathPrefix = './';

  function traverseDir(currentDir) {
    const files = fs.readdirSync(currentDir);

    for (const file of files) {
      let filePath;

      filePath = path.join(currentDir, file);
      const stats = fs.statSync(filePath);

      if (stats.isDirectory()) {
        traverseDir(filePath);
      } else {
        if (absolutePath) {
          filePath = path.resolve(filePath)
        }

        if (!fileMask || minimatch(file, fileMask)) {
          filePaths.push(`${pathPrefix}${filePath}`);
        }
      }
    }
  }

  traverseDir(rootDir);
  return filePaths;
}

export function getFullPath(moduleName, modulePath) {
  const __filename = fileURLToPath(moduleName);
  const __dirname = dirname(__filename);
  return path.join(__dirname, modulePath);
}